@@ -1,27 +1,26 @@
 import astroid
-from astroid import scoped_nodes
+from astroid import nodes
 
-from pylint.interfaces import IAstroidChecker
 from pylint.checkers import BaseChecker
 
 
-class AlphabeticallySortedImports(BaseChecker):
-    __implements__ = IAstroidChecker
+class ModuleOnlyImports(BaseChecker):
+    name = "check-if-we-import-only-modules"
 
-    name = 'check-if-we-import-only-modules'
-
-    ONLY_IMPORTING_MODULES_IS_ALLOWED = 'only-importing-modules-is-allowed'
+    ONLY_IMPORTING_MODULES_IS_ALLOWED = "only-importing-modules-is-allowed"
 
     msgs = {
-        'C5101': ('"%s" shouldn\'t be imported directly.',
-                  ONLY_IMPORTING_MODULES_IS_ALLOWED,
-                  ''),
+        "C5101": (
+            '"%s" shouldn\'t be imported directly.',
+            ONLY_IMPORTING_MODULES_IS_ALLOWED,
+            "",
+        ),
     }
     options = ()
 
     priority = -1
 
-    excluded_modules = ['typing', 'typing_extensions', 'six.moves']
+    excluded_modules = ["typing", "typing_extensions", "six.moves", "collections.abc", "__future__"]
 
     def visit_importfrom(self, node):
         imported = node.do_import_module()
@@ -35,7 +34,7 @@ class AlphabeticallySortedImports(BaseChecker):
                 # it's not there, so probably this is another module - fine.
                 continue
             imported_node, *_ = result
-            if isinstance(imported_node, scoped_nodes.Module):
+            if isinstance(imported_node, nodes.Module):
                 continue
 
             # maybe a submodule?
@@ -43,10 +42,9 @@ class AlphabeticallySortedImports(BaseChecker):
                 imported.import_module(name, relative_only=True)
             except astroid.AstroidImportError:
                 self.add_message(
-                    self.ONLY_IMPORTING_MODULES_IS_ALLOWED,
-                    node=node,
-                    args=(name, )
+                    self.ONLY_IMPORTING_MODULES_IS_ALLOWED, node=node, args=(name,)
                 )
 
+
 def register(linter):
-    linter.register_checker(AlphabeticallySortedImports(linter))
+    linter.register_checker(ModuleOnlyImports(linter))
